@@ -134,6 +134,7 @@ from typing import (
     Tuple,
     Any,
     ByteString,
+    Generator,
     no_type_check,
     get_type_hints
 )
@@ -670,7 +671,7 @@ class Executable(ABCMeta):
                 known.kwargs.pop('dest', None)
                 if 'default' in known.kwargs:
                     known.kwargs.setdefault('nargs', OPTIONAL)
-            elif not any(a.startswith('--') for a in known.args):
+            elif not any(len(a) > 2 for a in known.args):
                 flagname = known.destination.replace('_', '-')
                 known.args.append(F'--{flagname}')
             action = known.kwargs.get('action', 'store')
@@ -1179,7 +1180,7 @@ class Unit(UnitBase, abstract=True):
         if self._framed:
             return self._framed
 
-        def normalized_action(data: ByteString) -> Iterable[Chunk]:
+        def normalized_action(data: ByteString) -> Generator[Chunk, None, None]:
             try:
                 result = self.act(data)
                 if inspect.isgenerator(result):
@@ -1692,9 +1693,9 @@ class Unit(UnitBase, abstract=True):
                 with open(os.devnull, 'wb') if unit.args.devnull else sys.stdout.buffer as output:
                     source | unit | output
             except ArgumentTypeError as E:
-                unit.logger.info('delayed argument initialization failed:', str(E))
+                unit.logger.error(F'delayed argument initialization failed for argument "{E!s}"')
             except KeyboardInterrupt:
-                unit.logger.info('aborting due to keyboard interrupt')
+                unit.logger.warning('aborting due to keyboard interrupt')
             except OSError:
                 pass
 
