@@ -82,6 +82,7 @@ class xtp(PatternExtractor):
         'openxmlformats.org'      : 1,
         'purl.org'                : 1,
         'python.org'              : 1,
+        'sectigo.com'             : 1,
         'skype.com'               : 1,
         'sourceforge.net'         : 4,
         'sway-cdn.com'            : 1,
@@ -91,6 +92,7 @@ class xtp(PatternExtractor):
         'symcb.com'               : 1,
         'symcd.com'               : 1,
         'thawte.com'              : 1,
+        'usertrust.com'           : 1,
         'verisign.com'            : 1,
         'w3.org'                  : 1,
         'wikipedia.org'           : 1,
